@@ -45,7 +45,7 @@ const char *helpText[NUM_TOPICS] = {
 "\n\
 Twpsk is a sound card program that allows you to transmit and receive \
 PSK31, the digital mode developed by Peter, G3PLX. It has a \
-Graphical User Interface (GUI) which uses the Motif or lessTiff libraries. \n\
+Graphical User Interface (GUI) which uses the Motif or lesstiff libraries. \n\
 \n\
 The GUI consists of the main window and several other windows that you \
 pop up as needed. The main window has five sections: a Menu Bar, \
@@ -406,7 +406,7 @@ Rx Freq described above. \n\
 \n\
 NET \n\
 The NET button automates the setting of the Tx Freq. When the NET button \
-is on, the current frequency in the Rx Freq will be transfered to the \
+is on, the current frequency in the Rx Freq will be transferred to the \
 Tx Freq when you click on the Xmit button. This insure that you are \
 transmitting on the same frequency that you were receiving. If it is off, \
 and the Rx Freq and Tx Freq are different, you will be operating in a \
