@@ -22,10 +22,7 @@
 #ifndef INCLUDED_TWPSKCB_H
 #define INCLUDED_TWPSKCB_H
 
-#define KEY 6146
-// in GUI.h #define MAXCALL 12
-#define SHMSIZE 2 * MAXCALL
-
+#include "SHM.h"
 #include <Xm/XmP.h>
 
 class TwpskCB 
